;; Generated package description from jarchive.el  -*- no-byte-compile: t -*-
(define-package "jarchive" "0.6.0.0.20221113.160102" "Open project dependencies in jar archives" '((emacs "26.1")) :commit "2eb44fdf37676d3715fc8e8e789ce6ca2566db16" :maintainer '("Danny Freeman" . "danny@dfreeman.email") :keywords '("tools" "languages" "jvm" "java" "clojure") :url "https://git.sr.ht/~dannyfreeman/jarchive")
